@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Koha;
 # ABSTRACT: Lien à Koha
-$Koha::Contrib::Sudoc::Koha::VERSION = '2.03';
+$Koha::Contrib::Sudoc::Koha::VERSION = '2.04';
 use Moose;
 use Modern::Perl;
 use Carp;
@@ -170,8 +170,6 @@ sub get_biblio_by_ppn {
 }
 
 
-# Retrouve les notices associées à une autorité Koha identifiée par son authid
-# Retourne un tableau de (biblionumner, framework, record)
 sub get_biblios_by_authid {
     my ($self, $authid) = @_;
 
@@ -191,7 +189,7 @@ sub get_biblios_by_authid {
     return @records;
 }
 
-# Lecture d'une autorité par son PPN
+
 sub get_auth_by_ppn {
     my ($self, $ppn) = @_;
     my ($rs, $authid, $record);
@@ -208,8 +206,6 @@ sub get_auth_by_ppn {
 }
 
 
-
-
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -226,13 +222,21 @@ Koha::Contrib::Sudoc::Koha - Lien Ã  Koha
 
 =head1 VERSION
 
-version 2.03
+version 2.04
 
 =head1 DESCRIPTION
 
-=head1 NAME
+=head1 METHODS
 
-Koha - Class exposing info about a Koha instance.
+=head2 get_biblios_by_authid
+
+Retrouve les notices associées à une autorité Koha identifiée par son
+C<authid> Retourne un tableau de (biblionumner, framework, record)
+
+=head2 get_auth_by_ppn
+
+Lecture d'une autorité par son PPN. Renvoie un tableau contenant deux entrées:
+l'authid de l'autorité et l'enregistrement de l'autorité trouvée.
 
 =head1 SYNOPSYS
 
@@ -242,15 +246,6 @@ Koha - Class exposing info about a Koha instance.
 
   my $k2 = Koha->new( conf_file => '/usr/koha/world-library/etc/koha-conf.xml' );
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2015 by Tamil, s.a.r.l.
-
-L<http://www.tamil.fr>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 AUTHOR
 
 Frédéric Demians <f.demians@tamil.fr>
