@@ -1,13 +1,14 @@
 package Koha::Contrib::Sudoc::Loader::Biblios;
 # ABSTRACT: Chargeur de notices biblio
-$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.03';
+$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.04';
 use Moose;
 
 extends 'Koha::Contrib::Sudoc::Loader';
 
 use Modern::Perl;
 use YAML;
-use Locale::Messages;
+use C4::Biblio;
+use C4::Items;
 
 
 
@@ -42,12 +43,6 @@ sub doublons_sudoc {
 sub handle_record {
     my ($self, $record) = @_;
 
-    # FIXME: Ici et pas en-tête parce qu'il faut que l'environnement Shell soit
-    # déjà fixé avant de charger ces modules qui ont besoin de KOHA_CONF et qui
-    # le garde
-    use C4::Biblio;
-    use C4::Items;
-
     # FIXME Reset de la connexion tous les x enregistrements
     $self->sudoc->koha->zconn_reset()  unless $self->count % 10;
 
@@ -171,7 +166,7 @@ Koha::Contrib::Sudoc::Loader::Biblios - Chargeur de notices biblio
 
 =head1 VERSION
 
-version 2.03
+version 2.04
 
 =head1 AUTHOR
 
