@@ -1,17 +1,13 @@
 package Koha::Contrib::Sudoc::Spool;
 # ABSTRACT: Spool des fichiers de notices
-$Koha::Contrib::Sudoc::Spool::VERSION = '2.03';
+$Koha::Contrib::Sudoc::Spool::VERSION = '2.04';
 use Moose;
 use Modern::Perl;
 use File::Copy;
 use DateTime;
 use Format::Human::Bytes;
 
-# Le spool se trouve dans le sous-répertore var/spool du répertoire racine
-# pointé par la variable d'environnement SUDOC. Les fichiers arrivent de
-# l'ABES dans le répertoire 'staged'. Puis quand ils sont entièrement
-# téléchargés, ils sont déplacés en 'waiting'. De là, ils sont chargés un à un
-# dans Koha. Après chargement, ils sont déplacés en 'done'.
+
 
 my $dirstatus = [
     [
@@ -80,10 +76,6 @@ sub _sortable_name {
 }
 
 
-# Retourne les fichiers d'une categorie (staged/waiting/done) et d'un
-# type donnée. Par ex: 
-# $files = $spool->file('waiting', 'c');
-# $files = $spool->file('done', '[a|b]');
 sub files {
     my ($self, $where, $type) = @_;
     my $dir = $self->root . "/$where";
@@ -93,7 +85,6 @@ sub files {
 }
 
 
-# Retourne le premier lot de fichiers d'une catégorie et d'un type donnée
 sub first_batch_files {
     my ($self, $where, $type) = @_;
 
@@ -111,9 +102,6 @@ sub first_batch_files {
 }
 
 
-# Retourne la pathname d'un fichier qu'on retrouve, dans l'ordre, soit
-# dans le spool 'waiting' soit dans le spool 'done'. Si le fichier
-# n'existe pas, retourne undef.
 sub file_path {
     my ($self, $name) = @_;
     
@@ -125,7 +113,6 @@ sub file_path {
 }
 
 
-# Déplace un fichier dans le spool 'done'
 sub move_done {
     my ($self, $name) = @_;
     my $path = $self->root . "/waiting/$name";
@@ -135,7 +122,6 @@ sub move_done {
 }
 
 
-# Déplace tous les fichiers de l'ILN courant de staged dans waiting
 sub staged_to_waiting {
     my $self = shift;
     
@@ -149,7 +135,6 @@ sub staged_to_waiting {
 }
 
 
-# Liste le contenu des répertoires du spool
 sub list {
     my $self = shift;
     for ( @$dirstatus ) {
@@ -204,7 +189,56 @@ Koha::Contrib::Sudoc::Spool - Spool des fichiers de notices
 
 =head1 VERSION
 
-version 2.03
+version 2.04
+
+=head1 DESCRIPTION
+
+Le spool se trouve dans le sous-répertore C<var/spool> du répertoire racine
+pointé par la variable d'environnement C<SUDOC>. Les fichiers arrivent de
+l'ABES dans le répertoire C<staged>. Puis quand ils sont entièrement
+téléchargés, ils sont déplacés en C<waiting>. De là, ils sont chargés un à un
+dans Koha. Après chargement, ils sont déplacés en C<done>.
+
+=head1 METHODS
+
+=head2 files
+
+Retourne les fichiers d'une categorie (staged/waiting/done) et d'un
+type donnée. Par ex: 
+
+ $files = $spool->file('waiting', 'c');
+ $files = $spool->file('done', '[a|b]');
+
+=head2 first_batch_files($where, $type)
+
+Retourne dans un tableau le premier lot de fichiers d'une catégorie et d'un
+type donnée. For example:
+
+ my @files = $spool->first_batch_files('waiting', '[a|b]');
+
+=head2 file_path($name)
+
+Retourne la pathname d'un fichier qu'on retrouve, dans l'ordre, soit
+dans le spool C<waiting> soit dans le spool C<done>. Si le fichier
+n'existe pas, retourne undef.
+
+=head2 move_done($name)
+
+Déplace un fichier dans le spool 'done'
+
+=head2 staged_to_waiting
+
+Déplace tous les fichiers de l'ILN courant de staged dans waiting
+
+=head2 list
+
+Liste le contenu des répertoires du spool
+
+=head2 command
+
+Sans paramètre, liste le contenu des répertoires du spool, en appelant
+L<list>. Les paramètres sont des noms de fichiers du spool. Leur contenu est
+affiché.
 
 =head1 AUTHOR
 
