@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::TransferDaemon;
 # ABSTRACT: Service de transfert de fichiers
-$Koha::Contrib::Sudoc::TransferDaemon::VERSION = '2.03';
+$Koha::Contrib::Sudoc::TransferDaemon::VERSION = '2.04';
 use Moose;
 use Modern::Perl;
 use AnyEvent;
@@ -79,7 +79,7 @@ sub send_gtd {
     my $year = DateTime->now->year;
 
     $self->log->notice(
-        "Réception message 'status 9'. Envoi GTD: ILN $iln, job $jobid, année $year\n" );
+        "Réception 'status 9'. Envoi GTD: ILN $iln, job $jobid, année $year\n" );
 
     my $c = $self->sudoc->c->{trans};
 
@@ -106,7 +106,7 @@ sub send_gtd {
 
 sub move_to_waiting {
     my $self = shift;
-    $self->log->notice("Réception message 'status 0'. Fin transfert. Déplacement de 'done' à 'waiting'\n");
+    $self->log->notice("Réception 'status 0'. Fin transfert: 'staged' déplacé en 'waiting'\n");
     $self->sudoc->spool->staged_to_waiting();
 }
 
@@ -143,7 +143,7 @@ Koha::Contrib::Sudoc::TransferDaemon - Service de transfert de fichiers
 
 =head1 VERSION
 
-version 2.03
+version 2.04
 
 =head1 AUTHOR
 
